# DeltaPD

[![PyPI](https://img.shields.io/pypi/v/deltapd.svg)](https://pypi.python.org/pypi/deltapd)
[![DOI](https://zenodo.org/badge/303236865.svg)](https://zenodo.org/badge/latestdoi/303236865)

DeltaPD is a tool used to determine outliers in a gene tree when compared against a reference tree.

_Note: This project is currently in development and is not recommended for public use._

## Installation

To install DeltaPD, simply run:

```bash
python -m pip install deltapd
```

Following installation, it will then be on the path. The help menu can be accessed via: `deltapd -h`

## Documentation
For more information, read the documentation here: https://ecogenomics.github.io/DeltaPD/
